translate.tools.poconflicts.ConflictOptionParser

Package translate :: Package tools :: Module poconflicts :: Class ConflictOptionParser |
[hide private]
[frames] | no frames]

# Class ConflictOptionParser

source code

a specialized Option Parser for the conflict tool...

Instance Methods | [hide private]
parse_args(self, args=None, values=None) parses the command line options, handling implicit input/output args | source code
set_usage(self, usage=None) sets the usage string - if usage not given, uses getusagestring for each option | source code
run(self) parses the arguments, and runs recursiveprocess with the resulting options | source code
recursiveprocess(self, options) recurse through directories and process files | source code
clean(self, string, options) returns the cleaned string that contains the text to be matched | source code
processfile(self, fileprocessor, options, fullinputpath) process an individual file | source code
flatten(self, text, joinchar) flattens text to just be words | source code
buildconflictmap(self) work out which strings are conflicting | source code
outputconflicts(self, options) saves the result of the conflict match | source code
Inherited from `misc.optrecurse.RecursiveOptionParser`: `__init__`, `checkoutputsubdir`, `define_option`, `finalizetempoutputfile`, `format_manpage`, `get_prog_name`, `getformathelp`, `getfullinputpath`, `getfulloutputpath`, `getfulltemplatepath`, `getoutputname`, `getoutputoptions`, `getpassthroughoptions`, `gettemplatename`, `getusageman`, `getusagestring`, `initprogressbar`, `isexcluded`, `isrecursive`, `isvalidinputname`, `mkdir`, `openinputfile`, `openoutputfile`, `opentemplatefile`, `opentempoutputfile`, `print_manpage`, `recurseinputfilelist`, `recurseinputfiles`, `reportprogress`, `seterrorleveloptions`, `setformats`, `setmanpageoption`, `setprogressoptions`, `setpsycooption`, `splitext`, `splitinputext`, `splittemplateext`, `templateexists`, `usepsyco`, `warning` Inherited from `optparse.OptionParser`: `add_option_group`, `check_values`, `destroy`, `disable_interspersed_args`, `enable_interspersed_args`, `error`, `exit`, `expand_prog_name`, `format_epilog`, `format_help`, `format_option_help`, `get_default_values`, `get_description`, `get_option_group`, `get_usage`, `get_version`, `print_help`, `print_usage`, `print_version`, `set_default`, `set_defaults`, `set_process_default_values` Inherited from `optparse.OptionParser` (private): `_add_help_option`, `_add_version_option`, `_create_option_list`, `_get_all_options`, `_get_args`, `_get_encoding`, `_init_parsing_state`, `_match_long_opt`, `_populate_option_list`, `_process_args`, `_process_long_opt`, `_process_short_opts` Inherited from `optparse.OptionContainer`: `add_option`, `add_options`, `format_description`, `get_option`, `has_option`, `remove_option`, `set_conflict_handler`, `set_description` Inherited from `optparse.OptionContainer` (private): `_check_conflict`, `_create_option_mappings`, `_share_option_mappings` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `optparse.OptionParser`: `standard_option_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### parse_args(self, args=None, values=None) | source code
parses the command line options, handling implicit input/output args Overrides: optparse.OptionParser.parse_args

### set_usage(self, usage=None) | source code
sets the usage string - if usage not given, uses getusagestring for each option Overrides: optparse.OptionParser.set_usage

### run(self) | source code
parses the arguments, and runs recursiveprocess with the resulting options Overrides: misc.optrecurse.RecursiveOptionParser.run

### recursiveprocess(self, options) | source code
recurse through directories and process files Overrides: misc.optrecurse.RecursiveOptionParser.recursiveprocess

### processfile(self, fileprocessor, options, fullinputpath) | source code
process an individual file Overrides: misc.optrecurse.RecursiveOptionParser.processfile